from setuptools import setup, find_packages

setup(
    name='CloakSDK',
    version='0.0.0.1',
    packages=find_packages(),
    author='frane',
    author_email='autismguy843@gmail.com',
    description='Simple framework to text',
    classifiers=[
        "Development Status :: 4 - Beta",
        "Natural Language :: Polish",
        "Programming Language :: Python :: 3.12",
    ]
)
